herosdevices.hardware.raspberrypi.dhtxx - Heros Devices 0.6.0 documentation

Skip to content
Back to top
View this page

# herosdevices.hardware.raspberrypi.dhtxx

Drivers for the DHT11 and DHT22 temperature/humidity sensors.

## Module Contents

class herosdevices.hardware.raspberrypi.dhtxx.DHTxx(device: Literal[11, 22] = 22, pin_name: int | str = 4)

  Class to support reading temperatures and humidities from the DHT11 and DHT22 onewire sensors.

  This class builds on the “Adafruit_DHT” python package.

  device = 22
  pin